summaryrefslogtreecommitdiffstats
path: root/include/usrp_uhd/device.hpp
diff options
context:
space:
mode:
authorJosh Blum <josh@joshknows.com>2010-01-29 16:07:14 -0800
committerJosh Blum <josh@joshknows.com>2010-01-29 16:07:14 -0800
commit027cfcb163451d76c1fb711e0ae1fadf064dc996 (patch)
tree0eddf7bb2049627f2873be46bc0331307fc4d303 /include/usrp_uhd/device.hpp
parent30a8d2ecc36ce8ad6c01032e514ac66a277f06d0 (diff)
downloaduhd-027cfcb163451d76c1fb711e0ae1fadf064dc996.tar.gz
uhd-027cfcb163451d76c1fb711e0ae1fadf064dc996.tar.bz2
uhd-027cfcb163451d76c1fb711e0ae1fadf064dc996.zip
added utility convenience tune function (wip)
Diffstat (limited to 'include/usrp_uhd/device.hpp')
-rw-r--r--include/usrp_uhd/device.hpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/usrp_uhd/device.hpp b/include/usrp_uhd/device.hpp
index 3ef4a79cf..73f28e2cd 100644
--- a/include/usrp_uhd/device.hpp
+++ b/include/usrp_uhd/device.hpp
@@ -11,8 +11,8 @@
#include <boost/utility.hpp>
#include <boost/shared_ptr.hpp>
#include <boost/function.hpp>
-#include <vector>
#include <boost/asio/buffer.hpp>
+#include <vector>
namespace usrp_uhd{
@@ -26,9 +26,9 @@ public:
typedef boost::shared_ptr<device> sptr;
//argument types for send and recv raw methods
//the send args is convertable to a boost asio buffer
//the recv args is a callback that takes a boost asio buffer
- typedef boost::asio::const_buffer send_args_t;
+ typedef std::vector<boost::asio::const_buffer> send_args_t;
typedef boost::function<bool(const boost::asio::const_buffer &)> recv_args_t;
//structors
@@ -26,9 +26,9 @@ public:
typedef boost::shared_ptr<device> sptr;
//argument types for send and recv raw methods
- //the send args is convertable to a boost asio buffer
+ //the send args is a vector of the boost asio buffers
//the recv args is a callback that takes a boost asio buffer